Road Map
==============

1.0.0
-----
* Combine template tag libraries into skeleton. Tags will retain their name, but will require only one load.
* Use Git submodules for external libraries.
* Remove block ios_fix